@@ -129,10 +129,6 @@ static void _freePrepared(T C) {
 /* ----------------------------------------------------- Protected methods */
 
 
-#ifdef PACKAGE_PROTECTED
-#pragma GCC visibility push(hidden)
-#endif
-
 T Connection_new(void *pool, char **error) {
         assert(pool);
         T C;
@@ -163,7 +159,7 @@ void Connection_free(T *C) {
 }
 
 
-void Connection_setAvailable(T C, int isAvailable) {
+void Connection_setAvailable(T C, bool isAvailable) {
         assert(C);
         C->isAvailable = isAvailable;
         C->lastAccessedTime = Time_now();
@@ -187,10 +183,6 @@ bool Connection_isInTransaction(T C) {
         return (C->isInTransaction > 0);
 }
 
-#ifdef PACKAGE_PROTECTED
-#pragma GCC visibility pop
-#endif
-
 
 /* ------------------------------------------------------------ Properties */
 
