@@ -52,12 +52,12 @@
  * methods ConnectionPool_setInitialConnections() and 
  * ConnectionPool_setMaxConnections(). 
  *
- * <h2>Supported database systems:</h2>
+ * <h2 class="desc">Supported database systems:</h2>
  * This library may be built with support for many different database 
  * systems. To test if a particular system is supported use the method 
  * Connection_isSupported().  
  *
- * <h2>Life-cycle methods:</h2>
+ * <h2 class="desc">Life-cycle methods:</h2>
  * Clients should call ConnectionPool_start() to establish the connection pool 
  * against the database server before using the pool. To shutdown 
  * connections from the database server use ConnectionPool_stop(). Set
@@ -69,17 +69,15 @@
  * size of the pool
  
  *
- * <h2>Connection URL:</h2>
+ * <h2 class="desc">Connection URL:</h2>
  * The URL given to a Connection Pool at creation time specify a database 
  * connection on the standard URL format. The format of the connection URL 
  * is defined as:
  *
- * \htmlonly
- * <center><code>
+ * <pre>
  * database://[user:password@][host][:port]/database[?propertyName1][=propertyValue1][&propertyName2][=propertyValue2]...
- * </code></center>
- * \endhtmlonly
- * 
+ * </pre>
+ *
  * The property names <code>user</code> and <code>password</code> are always
  * recognized and specify how to login to the database. Other properties 
  * depends on the database server in question. User name and password can 
@@ -91,21 +89,17 @@
  * Here is an example on how to connect to a <a href="http://www.mysql.org/">
  * MySQL</a> database server:
  *
- * \htmlonly
- * <dt><dd><code>
- * mysql://localhost:3306/test?user=root&password=swordfish<br/>
- * </code></dd></dt>
- * \endhtmlonly
+ * <pre>
+ * mysql://localhost:3306/test?user=root&password=swordfish
+ * </pre>
  *
  * In this case the username, <code>root</code> and password, <code>swordfish
  * </code> are specified as properties to the URL. An alternative is to 
  * use the auth-part of the URL to specify authentication information:
  *
- * \htmlonly
- * <dt><dd><code>
- * mysql://root:swordfish@localhost:3306/test
- * </code></dd></dt>
- * \endhtmlonly
+ * <pre>
+ * mysql://root:swordfish\@localhost:3306/test
+ * </pre>
  *
  * See <a href="mysqloptions.html">mysql options</a> for all properties that
  * can be set for a mysql connection URL.
@@ -127,33 +121,27 @@
  * An URL for 
  * connecting to a SQLite database might look like:
  *
- * \htmlonly
- * <dt><dd><code>
+ * <pre>
  * sqlite:///var/sqlite/test.db?synchronous=normal&heap_limit=8000&foreign_keys=on
- * </code></dd></dt>
- * \endhtmlonly
+ * </pre>
  *
  * <h4>PostgreSQL:</h4>
  *
  * The URL for connecting to a <a href="http://www.postgresql.org/">
  * PostgreSQL</a> database server might look like:
  *
- * \htmlonly
- * <dt><dd><code>
- * postgresql://localhost:5432/test?user=root&password=swordfish<br/>
- * </code></dd></dt>
- * \endhtmlonly
+ * <pre>
+ * postgresql://localhost:5432/test?user=root&password=swordfish
+ * </pre>
  *
  * As with the MySQL URL, the username and password are specified as 
  * properties to the URL. Likewise, the auth-part of the URL can be used 
  * instead to specify the username and the password:
  *
- * \htmlonly
- * <dt><dd><code>
- * postgresql://root:swordfish@localhost/test?use-ssl=true
- * </code></dd></dt>
- * \endhtmlonly
- * 
+ * <pre>
+ * postgresql://root:swordfish\@localhost/test?use-ssl=true
+ * </pre>
+ *
  * In this example we have also omitted the port number to the server, in
  * which case the default port number, <i>5432</i>, for PostgreSQL is used. In
  * addition we have added an extra parameter to the URL, so connection to 
@@ -167,31 +155,30 @@
  * The URL for connecting to an <a href="http://www.oracle.com/">
  * Oracle</a> database server might look like:
  *
- * \htmlonly
- * <dt><dd><code>
- * oracle://localhost:1521/test?user=scott&password=tiger<br/>
- * </code></dd></dt>
- * \endhtmlonly
+ * <pre>
+ * oracle://localhost:1521/servicename?user=scott&password=tiger
+ * </pre>
  *
+ * Instead of a database name, Oracle uses a service name which you
+ * typically specify in a <code>tnsnames.ora</code> configuration file.
  * The auth-part of the URL can be used instead to specify the username 
- * and the password. In addition, you may specify a service name in the URL
- * instead if you have setup a <code>tnsnames.ora</code> configuration file.
+ * and the password as in the example below. Here we also specify that
+ * we want to connect to Oracle with the SYSDBA role.
  *
- * \htmlonly
- * <dt><dd><code>
- * oracle:///servicename?user=scott&password=tiger
- * </code></dd></dt>
- * \endhtmlonly
- *  
- * <h2>Example:</h2>
+ * <pre>
+ * oracle://sys:password\@localhost:1521/servicename?sysdba=true
+ * </pre>
+ *
+ * See <a href="oracleoptions.html">oracle options</a> for all properties that
+ * can be set for a oracle connection URL.
+ *
+ * <h2 class="desc">Example:</h2>
  * To obtain a connection pool for a MySQL database, the code below can be
  * used. The exact same code can be used for PostgreSQL, SQLite and Oracle, 
  * the only change needed is to modify the Connection URL. Here we connect
  * to the database test on localhost and start the pool with the default 5
  * initial connections.
  *
- * \htmlonly
- * <dt><dd><code>
  * <pre>
  * URL_T url = URL_new("mysql://localhost/test?user=root&password=swordfish");
  * ConnectionPool_T pool = ConnectionPool_new(url);
@@ -212,10 +199,8 @@
  * ConnectionPool_free(&pool);
  * URL_free(&url);
  * </pre>
- * </code></dd></dt>
- * \endhtmlonly
- * 
- * <h2>Optimizing the pool size:</h2>
+ *
+ * <h2 class="desc">Optimizing the pool size:</h2>
  * The pool can be setup to dynamically change the number of active 
  * Connections in the pool depending on the load. A single <code>reaper</code> 
  * thread can be activated at startup to sweep through the pool at a regular
@@ -233,7 +218,7 @@
  * It is recommended to start the pool with a reaper-thread, especially if
  * the pool maintains TCP/IP Connections.
  *
- * <h2>Realtime inspection:</h2>
+ * <h2 class="desc">Realtime inspection:</h2>
  * Two methods can be used to inspect the pool at runtime. The method 
  * ConnectionPool_size() returns the number of connections in the pool, that is,
  * both active and inactive connections. The method ConnectionPool_active() 
@@ -328,13 +313,12 @@ int ConnectionPool_getMaxConnections(T P);
 
 /**
  * Set a Connection inactive timeout value in seconds. The method,
- * ConnectionPool_reapConnections(), if called will close inactive 
+ * ConnectionPool_reapConnections(), if called, will close inactive
  * Connections in the pool which has not been in use since 
  * <code>connectionTimeout</code> seconds. Default connectionTimeout is 
- * 30 seconds. The reaper thread if in use, see ConnectionPool_setReaper(), 
- * also use this value when closing inactive Connections. It is a 
- * checked runtime error for <code>connectionTimeout</code> to be less than, 
- * or equal to zero.
+ * 30 seconds. The reaper thread, if in use, see ConnectionPool_setReaper(),
+ * uses this value when closing inactive Connections. It is a checked runtime
+ * error for <code>connectionTimeout</code> to be less than, or equal to zero.
  * @param P A ConnectionPool object
  * @param connectionTimeout The number of <code>seconds</code> a Connection 
  * can be inactive, i.e. not in use, before the reaper close the Connection. 
@@ -433,12 +417,29 @@ void ConnectionPool_stop(T P);
 /**
  * Get a connection from the pool
  * @param P A ConnectionPool object
- * @return A connection from the pool or NULL if maxConnection is reached
+ * @return A connection from the pool or NULL if maxConnection has been
+ * reached or if a database error occurred.
  * @see Connection.h
  */
 Connection_T ConnectionPool_getConnection(T P);
 
 
+/**
+ * Get a connection from the pool or throws an SQL Exception if a connection
+ * cannot be obtained. The method, ConnectionPool_getConnection() above, is
+ * identical except it will return null if the pool is full <strong>or</strong>
+ * if a database error occurs. This method will instead throw an SQL Exception
+ * in both cases with an appropriate error message.
+ * @param P A ConnectionPool object
+ * @return A connection from the pool or NULL if maxConnection has been
+ * reached or if a database error occurred.
+ * @exception SQLException If a database connection cannot be obtained. The
+ * error message is availble in Exception_frame.message
+ * @see Connection.h
+ */
+Connection_T ConnectionPool_getConnectionOrException(T P);
+
+
 /**
  * Returns a connection to the pool. The same as calling Connection_close()
  * @param P A ConnectionPool object
@@ -450,12 +451,15 @@ void ConnectionPool_returnConnection(T P, Connection_T connection);
 
 /**
  * Close all inactive Connections in the pool, down to initial connections. 
- * Inactive Connection are closed if and only if its 
- * <code>connectionTimeout</code> has expired <i>or</i> if the Connection 
+ * An inactive Connection is closed if and only if its
+ * <code>connectionTimeout</code> has expired <i>or</i> if the Connection
  * failed the ping test against the database. Active Connections are 
  * <i>not</i> closed by this method. 
  * @param P A ConnectionPool object
  * @return The number of Connections that was closed
+ * @see ConnectionPool_setConnectionTimeout
+ * @see ConnectionPool_setInitialConnections
+ * @see Connection_ping
  */
 int ConnectionPool_reapConnections(T P);
 
