@@ -3,12 +3,12 @@
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License version 3.
- * 
+ *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  *
@@ -27,13 +27,9 @@
 
 #include <stdio.h>
 #include <time.h>
-#include <sqlite3.h>
+#include <string.h>
 
-#include "system/Time.h"
-#include "ResultSet.h"
-#include "SQLiteResultSet.h"
-#include "PreparedStatementDelegate.h"
-#include "SQLitePreparedStatement.h"
+#include "SQLiteAdapter.h"
 
 
 /**
@@ -45,71 +41,55 @@
  */
 
 
-/* ----------------------------------------------------------- Definitions */
+/* ------------------------------------------------------------- Definitions */
 
 
-const struct Pop_T sqlite3pops = {
-        .name           = "sqlite",
-        .free           = SQLitePreparedStatement_free,
-        .setString      = SQLitePreparedStatement_setString,
-        .setInt         = SQLitePreparedStatement_setInt,
-        .setLLong       = SQLitePreparedStatement_setLLong,
-        .setDouble      = SQLitePreparedStatement_setDouble,
-        .setTimestamp   = SQLitePreparedStatement_setTimestamp,
-        .setBlob        = SQLitePreparedStatement_setBlob,
-        .execute        = SQLitePreparedStatement_execute,
-        .executeQuery   = SQLitePreparedStatement_executeQuery,
-        .rowsChanged    = SQLitePreparedStatement_rowsChanged
-};
-
 #define T PreparedStatementDelegate_T
 struct T {
         sqlite3 *db;
-        int maxRows;
         int lastError;
-	sqlite3_stmt *stmt;
+        sqlite3_stmt *stmt;
+        Connection_T delegator;
 };
-
 extern const struct Rop_T sqlite3rops;
 
 
-/* ----------------------------------------------------- Protected methods */
+/* ------------------------------------------------------------- Constructor */
 
 
-#ifdef PACKAGE_PROTECTED
-#pragma GCC visibility push(hidden)
-#endif
-
-T SQLitePreparedStatement_new(sqlite3 *db, void *stmt, int maxRows) {
+T SQLitePreparedStatement_new(Connection_T delegator, sqlite3_stmt *stmt) {
         T P;
         assert(stmt);
         NEW(P);
-        P->db = db;
+        P->delegator = delegator;
         P->stmt = stmt;
-        P->maxRows = maxRows;
+        P->db = sqlite3_db_handle(stmt);
         P->lastError = SQLITE_OK;
         return P;
 }
 
 
-void SQLitePreparedStatement_free(T *P) {
-	assert(P && *P);
-	sqlite3_finalize((*P)->stmt);
-	FREE(*P);
+/* -------------------------------------------------------- Delegate Methods */
+
+
+static void _free(T *P) {
+        assert(P && *P);
+        sqlite3_finalize((*P)->stmt);
+        FREE(*P);
 }
 
 
-void SQLitePreparedStatement_setString(T P, int parameterIndex, const char *x) {
+static void _setString(T P, int parameterIndex, const char *x) {
         assert(P);
         sqlite3_reset(P->stmt);
-        int size = x ? (int)strlen(x) : 0; 
+        int size = x ? (int)strlen(x) : 0;
         P->lastError = sqlite3_bind_text(P->stmt, parameterIndex, x, size, SQLITE_STATIC);
         if (P->lastError == SQLITE_RANGE)
                 THROW(SQLException, "Parameter index is out of range");
 }
 
 
-void SQLitePreparedStatement_setInt(T P, int parameterIndex, int x) {
+static void _setInt(T P, int parameterIndex, int x) {
         assert(P);
         sqlite3_reset(P->stmt);
         P->lastError = sqlite3_bind_int(P->stmt, parameterIndex, x);
@@ -118,7 +98,7 @@ void SQLitePreparedStatement_setInt(T P, int parameterIndex, int x) {
 }
 
 
-void SQLitePreparedStatement_setLLong(T P, int parameterIndex, long long x) {
+static void _setLLong(T P, int parameterIndex, long long x) {
         assert(P);
         sqlite3_reset(P->stmt);
         P->lastError = sqlite3_bind_int64(P->stmt, parameterIndex, x);
@@ -127,7 +107,7 @@ void SQLitePreparedStatement_setLLong(T P, int parameterIndex, long long x) {
 }
 
 
-void SQLitePreparedStatement_setDouble(T P, int parameterIndex, double x) {
+static void _setDouble(T P, int parameterIndex, double x) {
         assert(P);
         sqlite3_reset(P->stmt);
         P->lastError = sqlite3_bind_double(P->stmt, parameterIndex, x);
@@ -136,7 +116,7 @@ void SQLitePreparedStatement_setDouble(T P, int parameterIndex, double x) {
 }
 
 
-void SQLitePreparedStatement_setTimestamp(T P, int parameterIndex, time_t x) {
+static void _setTimestamp(T P, int parameterIndex, time_t x) {
         assert(P);
         sqlite3_reset(P->stmt);
         P->lastError = sqlite3_bind_int64(P->stmt, parameterIndex, x);
@@ -145,7 +125,7 @@ void SQLitePreparedStatement_setTimestamp(T P, int parameterIndex, time_t x) {
 }
 
 
-void SQLitePreparedStatement_setBlob(T P, int parameterIndex, const void *x, int size) {
+static void _setBlob(T P, int parameterIndex, const void *x, int size) {
         assert(P);
         sqlite3_reset(P->stmt);
         P->lastError = sqlite3_bind_blob(P->stmt, parameterIndex, x, size, SQLITE_STATIC);
@@ -154,16 +134,11 @@ void SQLitePreparedStatement_setBlob(T P, int parameterIndex, const void *x, int
 }
 
 
-void SQLitePreparedStatement_execute(T P) {
+static void _execute(T P) {
         assert(P);
-#if defined SQLITEUNLOCK && SQLITE_VERSION_NUMBER >= 3006012
-        P->lastError = sqlite3_blocking_step(P->stmt);
-#else
-        EXEC_SQLITE(P->lastError, sqlite3_step(P->stmt), SQL_DEFAULT_TIMEOUT);
-#endif
-        switch (P->lastError)
-        {
-                case SQLITE_DONE: 
+        P->lastError = zdb_sqlite3_step(P->stmt);
+        switch (P->lastError) {
+                case SQLITE_DONE:
                         P->lastError = sqlite3_reset(P->stmt);
                         break;
                 case SQLITE_ROW:
@@ -178,20 +153,43 @@ void SQLitePreparedStatement_execute(T P) {
 }
 
 
-ResultSet_T SQLitePreparedStatement_executeQuery(T P) {
+static ResultSet_T _executeQuery(T P) {
         assert(P);
         if (P->lastError == SQLITE_OK)
-                return ResultSet_new(SQLiteResultSet_new(P->stmt, P->maxRows, true), (Rop_T)&sqlite3rops);
+                return ResultSet_new(SQLiteResultSet_new(P->delegator, P->stmt, true), (Rop_T)&sqlite3rops);
         THROW(SQLException, "%s", sqlite3_errmsg(P->db));
         return NULL;
 }
 
 
-long long SQLitePreparedStatement_rowsChanged(T P) {
+static long long _rowsChanged(T P) {
         assert(P);
         return (long long)sqlite3_changes(P->db);
 }
 
-#ifdef PACKAGE_PROTECTED
-#pragma GCC visibility pop
-#endif
+
+static int _parameterCount(T P) {
+        assert(P);
+        return sqlite3_bind_parameter_count(P->stmt);
+}
+
+
+/* ------------------------------------------------------------------------- */
+
+
+const struct Pop_T sqlite3pops = {
+        .name           = "sqlite",
+        .free           = _free,
+        .setString      = _setString,
+        .setInt         = _setInt,
+        .setLLong       = _setLLong,
+        .setDouble      = _setDouble,
+        .setTimestamp   = _setTimestamp,
+        .setBlob        = _setBlob,
+        .execute        = _execute,
+        .executeQuery   = _executeQuery,
+        .rowsChanged    = _rowsChanged,
+        .parameterCount = _parameterCount
+};
+
+
